package sns_oauth_profile.client.invoker;

import java.util.logging.Logger;

import org.robotservices.custom_profile.lib.client.AbstractCustomProfile;
import org.robotservices.custom_profile.lib.client.InvokerCustomProfileFactory;
import org.robotservices.custom_profile.lib.client.PushDataCustomProfile;
import org.robotservices.custom_profile.lib.common.util.CustomProfileConst;
import org.robotservices.custom_profile.lib.common.util.HeaderTimeStampUtil;
import org.robotservices.custom_profile.lib.common.util.XMLUtil;
import org.robotservices.schemas.v02.common_profile.RetValue;
import org.robotservices.schemas.v02.common_profile.RoboHeader;
import org.robotservices.v02.exception.RSiException;

import sns_oauth_profile.common.SnsOauthProfileConst;
import sns_oauth_profile.common.SnsOauth_profile_end_profile;
import sns_oauth_profile.common.SnsOauth_profile_set_facebook_oauth_info_profile;
import sns_oauth_profile.common.SnsOauth_profile_set_googleplus_oauth_info_profile;
import sns_oauth_profile.common.SnsOauth_profile_set_twitter_oauth_info_profile;
import sns_oauth_profile.common.SnsOauth_profile_start_profile;

public class SnsOauthProfile extends AbstractCustomProfile implements ISnsOauth_profile {

	private static final Logger logger = Logger.getLogger(SnsOauthProfile.class.toString());

	@SuppressWarnings("rawtypes")
	public RetValue startProfile() throws RSiException {

		//XMLの作成
		RoboHeader roboHeader = new RoboHeader();
		roboHeader.setVersion(CustomProfileConst.ROBO_HEADER_VERSION);
		roboHeader.setDirection(CustomProfileConst.ROBO_HEADER_DIRECTION.CLtoSV.toString());
		roboHeader.setMessageType(CustomProfileConst.ROBO_HEADER_MESSAGE_TYPE.async.toString());
		roboHeader.setMessageId("MessageId");
		roboHeader.setReplyToMessageId("ReplyToMessageId");
		roboHeader.setLastReply(false);

		roboHeader.setTimestamp(HeaderTimeStampUtil.getHederTimeStampISO8601());

		SnsOauth_profile_start_profile snsOauth_profile_start_profile = new SnsOauth_profile_start_profile();

		snsOauth_profile_start_profile.setRoboHeader(roboHeader);

		String xml = XMLUtil.marshal(snsOauth_profile_start_profile);

		//カスタムプロファイル送信
		InvokerCustomProfileFactory invokerCustomProfileFactory = this.getInvokerCustomProfileFactory();
		PushDataCustomProfile pushDataCustomProfile = invokerCustomProfileFactory.getPushDataCustomProfile();

		String receiveXML = pushDataCustomProfile.pushDataCustomProfile(SnsOauthProfileConst.SERVICE_ACCEPTOR_CUSTOM_PROFILE_NAME,SnsOauthProfileConst.OPERATION_START_PROFILE, xml);
		RetValue retValue = XMLUtil.unmarshal(receiveXML, RetValue.class);

		return retValue;
	}

	@Override
	public RetValue endProfile() throws RSiException {
		//XMLの作成
		RoboHeader roboHeader = new RoboHeader();
		roboHeader.setVersion(CustomProfileConst.ROBO_HEADER_VERSION);
		roboHeader.setDirection(CustomProfileConst.ROBO_HEADER_DIRECTION.CLtoSV.toString());
		roboHeader.setMessageType(CustomProfileConst.ROBO_HEADER_MESSAGE_TYPE.async.toString());
		roboHeader.setMessageId("MessageId");
		roboHeader.setReplyToMessageId("ReplyToMessageId");
		roboHeader.setLastReply(false);

		roboHeader.setTimestamp(HeaderTimeStampUtil.getHederTimeStampISO8601());

		SnsOauth_profile_end_profile robotarm_profile_end_profile = new SnsOauth_profile_end_profile();

		robotarm_profile_end_profile.setRoboHeader(roboHeader);

		String xml = XMLUtil.marshal(robotarm_profile_end_profile);

		//カスタムプロファイル送信
		@SuppressWarnings("rawtypes")
		InvokerCustomProfileFactory invokerCustomProfileFactory = this.getInvokerCustomProfileFactory();
		PushDataCustomProfile pushDataCustomProfile = invokerCustomProfileFactory.getPushDataCustomProfile();

		String receiveXML = pushDataCustomProfile.pushDataCustomProfile(SnsOauthProfileConst.SERVICE_ACCEPTOR_CUSTOM_PROFILE_NAME,SnsOauthProfileConst.OPERATION_NAME_END_PROFILE, xml);

		RetValue retValue = XMLUtil.unmarshal(receiveXML, RetValue.class);
		return retValue;
	}

	@Override
	public RetValue setTwitterOauth(String consumer_key,
			String consumer_secret, String token_secret, String access_token,
			String screen_name) throws RSiException {

		//XMLの作成
		RoboHeader roboHeader = new RoboHeader();
		roboHeader.setVersion(CustomProfileConst.ROBO_HEADER_VERSION);
		roboHeader.setDirection(CustomProfileConst.ROBO_HEADER_DIRECTION.CLtoSV.toString());
		roboHeader.setMessageType(CustomProfileConst.ROBO_HEADER_MESSAGE_TYPE.async.toString());
		roboHeader.setMessageId("MessageId");
		roboHeader.setReplyToMessageId("ReplyToMessageId");
		roboHeader.setLastReply(false);

		roboHeader.setTimestamp(HeaderTimeStampUtil.getHederTimeStampISO8601());

		SnsOauth_profile_set_twitter_oauth_info_profile snsOauth_profile_set_twitter_oauth_info_profile = new SnsOauth_profile_set_twitter_oauth_info_profile();

		snsOauth_profile_set_twitter_oauth_info_profile.setRoboHeader(roboHeader);
		snsOauth_profile_set_twitter_oauth_info_profile.setConsumer_key(consumer_key);
		snsOauth_profile_set_twitter_oauth_info_profile.setConsumer_secret(consumer_secret);
		snsOauth_profile_set_twitter_oauth_info_profile.setToken_secret(token_secret);
		snsOauth_profile_set_twitter_oauth_info_profile.setAccess_token(access_token);
		snsOauth_profile_set_twitter_oauth_info_profile.setScreen_name(screen_name);

		String xml = XMLUtil.marshal(snsOauth_profile_set_twitter_oauth_info_profile);

		//カスタムプロファイル送信
		@SuppressWarnings("rawtypes")
		InvokerCustomProfileFactory invokerCustomProfileFactory = this.getInvokerCustomProfileFactory();
		PushDataCustomProfile pushDataCustomProfile = invokerCustomProfileFactory.getPushDataCustomProfile();

		String receiveXML = pushDataCustomProfile.pushDataCustomProfile(SnsOauthProfileConst.SERVICE_ACCEPTOR_CUSTOM_PROFILE_NAME,SnsOauthProfileConst.OPERATION_NAME_SET_TWITTER_OAUTH, xml);

		RetValue retValue = XMLUtil.unmarshal(receiveXML, RetValue.class);
		return retValue;
	}

	@Override
	public RetValue setFacebookOauth(String application_id,
			String access_token, String expire_in) throws RSiException {
		//XMLの作成
		RoboHeader roboHeader = new RoboHeader();
		roboHeader.setVersion(CustomProfileConst.ROBO_HEADER_VERSION);
		roboHeader.setDirection(CustomProfileConst.ROBO_HEADER_DIRECTION.CLtoSV.toString());
		roboHeader.setMessageType(CustomProfileConst.ROBO_HEADER_MESSAGE_TYPE.async.toString());
		roboHeader.setMessageId("MessageId");
		roboHeader.setReplyToMessageId("ReplyToMessageId");
		roboHeader.setLastReply(false);

		roboHeader.setTimestamp(HeaderTimeStampUtil.getHederTimeStampISO8601());

		SnsOauth_profile_set_facebook_oauth_info_profile snsOauth_profile_set_facebook_oauth_info_profile = new SnsOauth_profile_set_facebook_oauth_info_profile();

		snsOauth_profile_set_facebook_oauth_info_profile.setRoboHeader(roboHeader);
		snsOauth_profile_set_facebook_oauth_info_profile.setApplication_id(application_id);
		snsOauth_profile_set_facebook_oauth_info_profile.setAccess_token(access_token);
		snsOauth_profile_set_facebook_oauth_info_profile.setExpire_in(expire_in);

		String xml = XMLUtil.marshal(snsOauth_profile_set_facebook_oauth_info_profile);

		//カスタムプロファイル送信
		@SuppressWarnings("rawtypes")
		InvokerCustomProfileFactory invokerCustomProfileFactory = this.getInvokerCustomProfileFactory();
		PushDataCustomProfile pushDataCustomProfile = invokerCustomProfileFactory.getPushDataCustomProfile();

		String receiveXML = pushDataCustomProfile.pushDataCustomProfile(SnsOauthProfileConst.SERVICE_ACCEPTOR_CUSTOM_PROFILE_NAME,SnsOauthProfileConst.OPERATION_NAME_SET_FACEBOOK_OAUTH, xml);

		RetValue retValue = XMLUtil.unmarshal(receiveXML, RetValue.class);
		return retValue;
	}

	@Override
	public RetValue setgooglePlusOauth(String application_id, String client_id,
			String client_secret, String access_token, String token_type,
			String expires_in, String refresh_token) throws RSiException {
		//XMLの作成
		RoboHeader roboHeader = new RoboHeader();
		roboHeader.setVersion(CustomProfileConst.ROBO_HEADER_VERSION);
		roboHeader.setDirection(CustomProfileConst.ROBO_HEADER_DIRECTION.CLtoSV.toString());
		roboHeader.setMessageType(CustomProfileConst.ROBO_HEADER_MESSAGE_TYPE.async.toString());
		roboHeader.setMessageId("MessageId");
		roboHeader.setReplyToMessageId("ReplyToMessageId");
		roboHeader.setLastReply(false);

		roboHeader.setTimestamp(HeaderTimeStampUtil.getHederTimeStampISO8601());

		SnsOauth_profile_set_googleplus_oauth_info_profile snsOauth_profile_set_googleplus_oauth_info_profile = new SnsOauth_profile_set_googleplus_oauth_info_profile();

		snsOauth_profile_set_googleplus_oauth_info_profile.setRoboHeader(roboHeader);
		snsOauth_profile_set_googleplus_oauth_info_profile.setApplication_id(application_id);
		snsOauth_profile_set_googleplus_oauth_info_profile.setClient_id(client_id);
		snsOauth_profile_set_googleplus_oauth_info_profile.setClient_secret(client_secret);
		snsOauth_profile_set_googleplus_oauth_info_profile.setAccess_token(access_token);
		snsOauth_profile_set_googleplus_oauth_info_profile.setToken_type(token_type);
		snsOauth_profile_set_googleplus_oauth_info_profile.setExpires_in(expires_in);
		snsOauth_profile_set_googleplus_oauth_info_profile.setRefresh_token(refresh_token);

		String xml = XMLUtil.marshal(snsOauth_profile_set_googleplus_oauth_info_profile);

		//カスタムプロファイル送信
		@SuppressWarnings("rawtypes")
		InvokerCustomProfileFactory invokerCustomProfileFactory = this.getInvokerCustomProfileFactory();
		PushDataCustomProfile pushDataCustomProfile = invokerCustomProfileFactory.getPushDataCustomProfile();

		String receiveXML = pushDataCustomProfile.pushDataCustomProfile(SnsOauthProfileConst.SERVICE_ACCEPTOR_CUSTOM_PROFILE_NAME,SnsOauthProfileConst.OPERATION_NAME_SET_GOOGLE_PLUS_OAUTH, xml);

		RetValue retValue = XMLUtil.unmarshal(receiveXML, RetValue.class);
		return retValue;
	}


}